(*
 *	Copyright (c) 2002 by Laboratoire Spcification et Vrification (LSV),
 *	CNRS UMR 8643 & ENS Cachan.
 *	Written by Jean Goubault-Larrecq.  Not derived from licensed software.
 *
 *	Permission is granted to anyone to use this software for any
 *	purpose on any computer system, and to redistribute it freely,
 *	subject to the following restrictions:
 *
 *	1. Neither the author nor its employer is responsible for the 
 *         consequences of use of this software, no matter how awful, 
 *         even if they arise from defects in it.
 *
 *	2. The origin of this software must not be misrepresented, either
 *	   by explicit claim or by omission.
 *
 *	3. Altered versions must be plainly marked as such, and must not
 *	   be misrepresented as being the original software.
 *
 *	4. This software is restricted to non-commercial use only.  Commercial
 *	   use is subject to a specific license, obtainable from LSV.
 *	   This was developed as part of the EVA project; as such, access
 *	   to this software by partners of the RNTL EVA Project (Trusted
 *	   Logic S.A., Verimag) is defined by the intellectual property
 *	   agreement signed as part of this project.
 *)

(** Control and replacement of alias symbols in terms and 
  protocol specifications. *)  

open Location;;
open Abstract;;
open Symbols;;

(** raised by functions the [alias] module to signal errors 
  in the input file concerning aliases.
  - message
  - location of the error *)
exception Alias_error of string * location


(** [has_alias sl term]
  @return [true] if the given located term [term] contains
  a symbol registered as an alias in the given symbol list [sl].
  Returns [false] otherwise. 
  
  NB: It is assumes that only the leaves of the form [EVA_TERM_ID]
  and  [EVA_TERM_ALIAS] (see {!Abstract.eva_term}) can contain alias symbols.  *)
val has_alias : 
  eva_symbol_list -> eva_lterm -> bool


(** [unalias_lterm sl term]
   @return the term obtained by 
   replacement of the aliases in the given located term [term],
   according to the given symbol list [sl]. *)
val unalias_lterm :
  eva_symbol_list -> eva_lterm -> eva_lterm


(** [unalias_ldcl sl d]
  @return the given located declaration [d]
   after unaliasing the terms it contains, 
   only if the declaration is not an alias declaration. *)
val unalias_ldcl :
  eva_symbol_list -> eva_ldcl -> eva_ldcl


(** [unalias_dcl sl d]
  @return the given declaration [d]
   after unaliasing the terms it contains, 
   only if the declaration is not an alias declaration. *)
val unalias_dcl :
  eva_symbol_list -> eva_dcl -> eva_dcl

(** [unalias_spec sl sp]
  @return the given abstract specification [sp]
  after unaliasing all the terms it contains,
  except in the alias declarations *)
val unalias_spec :
  eva_symbol_list -> eva_spec -> eva_spec

