(*
 *	Copyright (c) 2002 by Laboratoire Spcification et Vrification (LSV),
 *	CNRS UMR 8643 & ENS Cachan.
 *	Written by Jean Goubault-Larrecq.  Not derived from licensed software.
 *
 *	Permission is granted to anyone to use this software for any
 *	purpose on any computer system, and to redistribute it freely,
 *	subject to the following restrictions:
 *
 *	1. Neither the author nor its employer is responsible for the 
 *         consequences of use of this software, no matter how awful, 
 *         even if they arise from defects in it.
 *
 *	2. The origin of this software must not be misrepresented, either
 *	   by explicit claim or by omission.
 *
 *	3. Altered versions must be plainly marked as such, and must not
 *	   be misrepresented as being the original software.
 *
 *	4. This software is restricted to non-commercial use only.  Commercial
 *	   use is subject to a specific license, obtainable from LSV.
 *	   This was developed as part of the EVA project; as such, access
 *	   to this software by partners of the RNTL EVA Project (Trusted
 *	   Logic S.A., Verimag) is defined by the intellectual property
 *	   agreement signed as part of this project.
 *)

open Printf;;

open Location;;

(* general kprintf from Damien Doligez *)
let (kaprintf : (string -> 'b) -> ('a, unit, 'b) format -> 'a) =
  fun kont fmt ->
    let fmt = (Obj.magic fmt : string) in
    let len = String.length fmt in
    let dest = Buffer.create (len + 16) in
    let rec doprn i =
      if i >= len 
      then 
        begin
          let res = Buffer.contents dest in
            Buffer.clear dest;  (* just in case kaprintf is partially applied *)
            Obj.magic (kont res)
        end 
      else
        match String.unsafe_get fmt i with
          | '%' -> Printf.scan_format fmt i cont_s cont_a cont_t
          |  c  -> Buffer.add_char dest c; doprn (succ i)
    and cont_s s i =
      Buffer.add_string dest s; doprn i
    and cont_a printer arg i =
      Buffer.add_string dest (printer () arg); doprn i
    and cont_t printer i =
      Buffer.add_string dest (printer ()); doprn i
    in doprn 0;;


(* Colors codes:
 * BLACK           0
 * RED             1
 * GREEN           2
 * YELLOW          3
 * BLUE            4
 * MAGENTA         5
 * CYAN            6
 * WHITE           7
 * 
 * Attributes codes:
 * RESET           0 Reset All Attributes (return to normal mode) 
 * BRIGHT          1 Usually turns on BOLD 
 * DIM             2
 * UNDERLINE       3
 * BLINK           4
 * REVERSE         7
 * HIDDEN          8
 *)


let internal_print prefix fmt =
  let k result = print_string (prefix^result);
  in kaprintf k fmt;;

let internal_fprint ch prefix fmt =
  let k result = fprintf ch "%s" (prefix^result);
  in kaprintf k fmt;;

let ignore fmt =
  kaprintf (fun x -> ()) fmt;;

(* print the given error message and the given location *)
let parse_error loc = 
  fprintf stderr;;


let error fmt = 
  internal_fprint stderr "" fmt;;

let warning fmt = 
  internal_fprint stderr "Warning: " fmt;;

