(*
 *	Copyright (c) 2002 by Laboratoire Spcification et Vrification (LSV),
 *	CNRS UMR 8643 & ENS Cachan.
 *	Written by Jean Goubault-Larrecq.  Not derived from licensed software.
 *
 *	Permission is granted to anyone to use this software for any
 *	purpose on any computer system, and to redistribute it freely,
 *	subject to the following restrictions:
 *
 *	1. Neither the author nor its employer is responsible for the 
 *         consequences of use of this software, no matter how awful, 
 *         even if they arise from defects in it.
 *
 *	2. The origin of this software must not be misrepresented, either
 *	   by explicit claim or by omission.
 *
 *	3. Altered versions must be plainly marked as such, and must not
 *	   be misrepresented as being the original software.
 *
 *	4. This software is restricted to non-commercial use only.  Commercial
 *	   use is subject to a specific license, obtainable from LSV.
 *	   This was developed as part of the EVA project; as such, access
 *	   to this software by partners of the RNTL EVA Project (Trusted
 *	   Logic S.A., Verimag) is defined by the intellectual property
 *	   agreement signed as part of this project.
 *)

open Format;;
open Location;;

(** Module for printing errors *)

(** prints on the standard output the concatenation 
  of the given string and of the given formatted message. 

  The formatted messages [format arg1 ... argn] 
  has the same form than for [printf].

  @see <http://caml.inria.fr/ocaml/htmlman/libref/Printf.html> the Ocaml module Printf *)
val internal_print :
  string -> ('a, unit, unit) format -> 'a

(** prints on the given output channel the concatenation 
  of the given string and of the given formatted message. *)
val internal_fprint :
  out_channel -> string -> ('a, unit, unit) format -> 'a

(** Do nothing. *)
val ignore :
 ('a, unit, unit) format -> 'a

(** report the given formatted error message on error output. *)
val error : 
  ('_a, unit, unit) format -> '_a

(** report the given formatted warning message on error output. *)
val warning :
  ('a, unit, unit) format -> 'a

