(*
 *	Copyright (c) 2002 by Laboratoire Spcification et Vrification (LSV),
 *	CNRS UMR 8643 & ENS Cachan.
 *	Written by Jean Goubault-Larrecq.  Not derived from licensed software.
 *
 *	Permission is granted to anyone to use this software for any
 *	purpose on any computer system, and to redistribute it freely,
 *	subject to the following restrictions:
 *
 *	1. Neither the author nor its employer is responsible for the 
 *         consequences of use of this software, no matter how awful, 
 *         even if they arise from defects in it.
 *
 *	2. The origin of this software must not be misrepresented, either
 *	   by explicit claim or by omission.
 *
 *	3. Altered versions must be plainly marked as such, and must not
 *	   be misrepresented as being the original software.
 *
 *	4. This software is restricted to non-commercial use only.  Commercial
 *	   use is subject to a specific license, obtainable from LSV.
 *	   This was developed as part of the EVA project; as such, access
 *	   to this software by partners of the RNTL EVA Project (Trusted
 *	   Logic S.A., Verimag) is defined by the intellectual property
 *	   agreement signed as part of this project.
 *)

(** Lexical analyser for protocol specifications in LAEVA concrete syntax *)


open Location;;
(* parser for tokens definitions *)
open Evaparse;;

(** unexpected end of file in comment *)
exception Eof_in_comment;;

(** invalid char
  - the unexpected char as a string 
  - the location of the invalid char *)
exception Invalid_char of string * location;;

(* set the name of the file processed *)
val set_filename :
  string -> unit

(** @return the name of the file currently processed, 
  returns "" (empty string) if no filename has been set.  *)
val get_filename :
  unit -> string

(** printa the current location on the standard output *)
val print_location :
  unit -> unit

(* @return a formatted string describing the current location *)
val string_of_location :
  unit -> string

 

(** @return the next token in the given [lexbuffer] *)
val evatoken : 
  Lexing.lexbuf -> Evaparse.token


