(*
 *	Copyright (c) 2002 by Laboratoire Spcification et Vrification (LSV),
 *	CNRS UMR 8643 & ENS Cachan.
 *	Written by Jean Goubault-Larrecq.  Not derived from licensed software.
 *
 *	Permission is granted to anyone to use this software for any
 *	purpose on any computer system, and to redistribute it freely,
 *	subject to the following restrictions:
 *
 *	1. Neither the author nor its employer is responsible for the 
 *         consequences of use of this software, no matter how awful, 
 *         even if they arise from defects in it.
 *
 *	2. The origin of this software must not be misrepresented, either
 *	   by explicit claim or by omission.
 *
 *	3. Altered versions must be plainly marked as such, and must not
 *	   be misrepresented as being the original software.
 *
 *	4. This software is restricted to non-commercial use only.  Commercial
 *	   use is subject to a specific license, obtainable from LSV.
 *	   This was developed as part of the EVA project; as such, access
 *	   to this software by partners of the RNTL EVA Project (Trusted
 *	   Logic S.A., Verimag) is defined by the intellectual property
 *	   agreement signed as part of this project.
 *)

open Format;;

type location =
{ 
  file : string; 
  start_line : int;
  end_line : int;  
  start_char : int;
  end_char : int 
}


let spawn startloc endloc =
  { file = startloc.file;
    start_line = startloc.start_line;
    start_char = startloc.start_char;
    end_line = endloc.end_line;
    end_char = endloc.end_char
  };;

let default_location =
  { 
    file = "";
    start_line = -1;
    start_char = -1;
    end_line = -1;
    end_char = -1
  };;

let print_location loc =
  begin
    open_box 0;
    print_string "file:";
    print_space ();
    print_string loc.file;
    print_space ();
    if ( loc.start_line = loc.end_line )
    then 
      begin
        print_string "line";
        print_space ();
        print_int loc.start_line;
        print_string ",";
        print_space ();
        if ( loc.start_char = loc.end_char )
        then
          begin
            print_string "col";
            print_space ();
            print_int loc.start_char;
          end
        else
          begin
            print_string "cols";
            print_space ();
            print_int loc.start_char;            
            print_string "-";
            print_int loc.end_char;    
          end
      end
    else
      begin
        print_string "line";
        print_space ();
        print_int loc.start_line;
        print_string ",";
        print_space (); 
        print_string "col";
        print_space ();
        print_int loc.start_char;
        print_space ();       
        print_string "to";
        print_space ();       
        print_string "line";
        print_space ();
        print_int loc.end_line;
        print_string ",";
        print_space (); 
        print_string "col";
        print_space ();
        print_int loc.end_char;
      end
  end
;;

(* returns a formatted string describing the given location *)
let string_of_location loc =
  if ( loc.start_line = loc.end_line )
  then sprintf "@[File \"%s\", line %i, %s@]"
    (* sprintf "@[file@ \"%s\"@],@ @[line %i@],@ @[%s@]" *)
    loc.file
    loc.start_line
    ( if ( loc.start_char = loc.end_char )
      then "character "^(string_of_int loc.start_char)
      else "characters "^(string_of_int loc.start_char)^"-"^(string_of_int loc.end_char) )
  else sprintf "@[File@ \"%s\"@],@ @[line %i, character %i@]@ -@ @[line %i, character %i@]"
    loc.file loc.start_line loc.start_char loc.end_line loc.end_char;;


