(*
 *	Copyright (c) 2002 by Laboratoire Spcification et Vrification (LSV),
 *	CNRS UMR 8643 & ENS Cachan.
 *	Written by Jean Goubault-Larrecq.  Not derived from licensed software.
 *
 *	Permission is granted to anyone to use this software for any
 *	purpose on any computer system, and to redistribute it freely,
 *	subject to the following restrictions:
 *
 *	1. Neither the author nor its employer is responsible for the 
 *         consequences of use of this software, no matter how awful, 
 *         even if they arise from defects in it.
 *
 *	2. The origin of this software must not be misrepresented, either
 *	   by explicit claim or by omission.
 *
 *	3. Altered versions must be plainly marked as such, and must not
 *	   be misrepresented as being the original software.
 *
 *	4. This software is restricted to non-commercial use only.  Commercial
 *	   use is subject to a specific license, obtainable from LSV.
 *	   This was developed as part of the EVA project; as such, access
 *	   to this software by partners of the RNTL EVA Project (Trusted
 *	   Logic S.A., Verimag) is defined by the intellectual property
 *	   agreement signed as part of this project.
 *)


(** Locations of the elements in a source file *)

(** Type of locations. *)
type location =
{ 
  file : string;    (** filename *)
  start_line : int; (** start line number *)
  end_line : int;   (** end line number *)
  start_char : int; (** start character position *)
  end_char : int    (** end character position *)
}

(** merge locations.
  @return a location with filename,
  starting line and column numbers as in the first given location, 
  and with end line and column numbers as as in the second given location. 
  @param l1 begin location
  @param l2 end location *)
val spawn: 
  location -> location -> location

(** pretty print the given location on standard output. *)
val print_location :
  location -> unit

(** @return a formatted string describing the given location. *)
val string_of_location :
  location -> string

(** default location. *)
val default_location : 
  location
